package jrummikub.model;

import java.awt.Color;

import jrummikub.control.turn.HumanTurnControl;
import jrummikub.control.turn.TurnControlFactory;

/**
 * The settings of a player
 */
public class PlayerSettings {
	private String name;
	private Color color;
	private TurnControlFactory turnControlFactory;

	/**
	 * Create a new player
	 * 
	 * @param name
	 *            the player's name
	 * @param color
	 *            the player's color
	 * @param turnControlFactory
	 *            the player's {@link TurnControlFactory}
	 */
	public PlayerSettings(String name, Color color,
			TurnControlFactory turnControlFactory) {
		this.name = name;
		this.color = color;
		this.turnControlFactory = turnControlFactory;
	}
	
	/**
	 * Create a new human player
	 * 
	 * @param name
	 *            the player's name
	 * @param color
	 *            the player's color
	 */
	public PlayerSettings(String name, Color color) {
		this.name = name;
		this.color = color;
		this.turnControlFactory = HumanTurnControl.getFactory();
	}

	/**
	 * Returns the player's color
	 * 
	 * @return the color
	 */
	public Color getColor() {
		return color;
	}

	/**
	 * Returns the player's name
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the player's color
	 * 
	 * @param color
	 *            the new color
	 */
	public void setColor(Color color) {
		this.color = color;
	}

	/**
	 * Sets the player's name
	 * 
	 * @param name
	 *            the new name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Set the player's TurnControlFactory
	 * 
	 * @param turnControlFactory
	 *            player's TurnControlFactory
	 */
	public void setTurnControlFactory(TurnControlFactory turnControlFactory) {
		this.turnControlFactory = turnControlFactory;
	}

	/**
	 * Get the player's TurnControlFactory
	 * 
	 * @return player's TurnControlFactory
	 */
	public TurnControlFactory getTurnControlFactory() {
		return turnControlFactory;
	}
}
